local ns = G13BarManager

--Build the empty Options panel
OptionsPanel = CreateFrame("Frame", "G13OptionsPanel", UIParent)
OptionsPanel.name = "G13 Bar Manager"
InterfaceOptions_AddCategory(OptionsPanel)

--Here we check the SavedVariables after the addon is loaded.
--These were obtained earlier in the core addon code file.
OptionsPanel:RegisterEvent("ADDON_LOADED")
OptionsPanel:SetScript("OnEvent", function(self)
	if G13BarManager.HKVis == false then
		HideHotKeys()
	end
	if G13BarManager.MenuVis == false then
		G13MenuBar:Hide()
	end
end)

--Set up the slash command
SLASH_G13BARMANAGER1 = '/g13'

function SlashCmdList.G13BARMANAGER(msg, editbox)
	--We have to call this twice because Blizzard UI behaves oddly.
	--You may think you can remove one.
	--You can't.  Really, please don't.
	--Doing so will make it fail on some systems.
	InterfaceOptionsFrame_OpenToCategory("G13 Bar Manager")
	InterfaceOptionsFrame_OpenToCategory("G13 Bar Manager")
end

--This is the button for toggling the MenuBar visibility.
local MenuBarButton = CreateFrame("Button","G13MenuBarButton", OptionsPanel, 'OptionsButtonTemplate') 
MenuBarButton:SetSize(150, 30)
MenuBarButton:SetPoint("TOPLEFT", OptionsPanel, 10, -10)
MenuBarButton:RegisterForClicks("AnyUp")
MenuBarButton:SetText("Toggle Menu Bar")
MenuBarButton:SetScript("OnClick", function(self, button)
	if G13BarManager.MenuVis == true then
		G13MenuBar:Hide()
		G13BarManager.MenuVis = false
	else
		G13MenuBar:Show()
		G13BarManager.MenuVis = true
	end
end)

--This is the button for toggling the HotKeys visibility.
local HotKeyButton = CreateFrame("Button","G13HotkeyButton", OptionsPanel, 'OptionsButtonTemplate') 
HotKeyButton:SetSize(150, 30)
HotKeyButton:SetPoint("TOPLEFT", MenuBarButton, "BOTTOMLEFT",  0, -10)
HotKeyButton:RegisterForClicks("AnyUp")
HotKeyButton:SetText("Toggle Hotkey Text")
HotKeyButton:SetScript("OnClick", function(self, button)
	if ActionButton1HotKey:GetAlpha() == 1 then
		HideHotKeys()
		G13BarManager.HKVis = false
	else
		ShowHotKeys()
		G13BarManager.HKVis = true
	end
end)

--This is a list of all the bars we have created. It could possibly be moved to the AllBars
--file, but for now it works here.  I'll revisit this during a code refactor, possibly.
local G13BarsList = {
	G13MainBar,
	G13BRBar,
	G13PetBar,
	G13StanceBar,
	G13BagBar,
	G13MenuBar
}

--This is a checkbutton to toggle the movability of the bars.
local BarLockCheckbutton = CreateFrame("CheckButton", "G13BarLockCheckbutton", OptionsPanel, 'OptionsCheckButtonTemplate')
BarLockCheckbutton:SetPoint("TOPLEFT", HotKeyButton, "BOTTOMLEFT",  0, -10)
_G[BarLockCheckbutton:GetName() .. "Text"]:SetText("Unlock Action Bars")
BarLockCheckbutton:SetScript("OnClick", function(self, checkbutton)
	if self:GetChecked() then
		HideAllButtons()
		for _, v in pairs(G13BarsList) do
			UnlockFrame(v)
		end
	else
		ShowAllButtons()
		for _, v in pairs(G13BarsList) do
			LockFrame(v)
		end
	end
end)